@@ -69,7 +69,7 @@ class GeoConfirmedExtractor():
         )
 
         # Example: "2022-10-10T16:20:00"
-        DATE_INPUT_FORMAT: str = "%Y-%m-%dT%H:%M%S"
+        DATE_INPUT_FORMAT: str = "%Y-%m-%dT%H:%M:%S"
 
         def parse_date(d: str) -> datetime:
             # Note: e.g. twitter.com/GeoConfirmed/status/1579567301963440128
@@ -113,6 +113,10 @@ class GeoConfirmedExtractor():
                     links=sources,
                     source=SOURCE_NAMES.GEOCONFIRMED,
                 )
+                # XXX REMOVEME ugly hack for faulty GeoConfirmed data
+                # e.g. dates like 1527-02-04T18:23:00
+                if event.date < datetime(2000, 1, 1):
+                    event.date = FALLBACK_DATE
                 events.append(event)
 
         return events
